@@ -323,9 +323,9 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "speed_tradeoff"
 	},
-	{ NAUTILUS_PREFERENCES_SHOW_SPECIAL_FLAGS,
+	{ NAUTILUS_PREFERENCES_SHOW_ADVANCED_PERMISSIONS,
 	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
+	  GINT_TO_POINTER (FALSE)
 	},
 	{ NAUTILUS_PREFERENCES_SORT_DIRECTORIES_FIRST,
 	  PREFERENCE_BOOLEAN,
@@ -384,6 +384,10 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_STRING,
 	  ""
 	},
+	{ NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_MAXIMIZED,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (FALSE)
+	},
 	{ NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
@@ -436,7 +440,11 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "default_zoom_level"
 	},
-
+	{ NAUTILUS_PREFERENCES_ICON_VIEW_THUMBNAIL_SIZE,
+	  PREFERENCE_INTEGER,
+	  GINT_TO_POINTER (96)
+	},
+	
 	/* List View Default Preferences */
 	{ NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_ORDER,
 	  PREFERENCE_STRING,
